@@ -22,11 +22,9 @@ from .circuit_linear_mapped import (
     LinearMappedUnboundParametricQuantumCircuitBase,
 )
 from .circuit_parametric import (
-    CONST,
     ImmutableBoundParametricQuantumCircuit,
     ImmutableUnboundParametricQuantumCircuit,
     MutableUnboundParametricQuantumCircuitProtocol,
-    Parameter,
     UnboundParametricQuantumCircuit,
     UnboundParametricQuantumCircuitBase,
     UnboundParametricQuantumCircuitProtocol,
@@ -40,6 +38,7 @@ from .gates import (
     RY,
     RZ,
     SWAP,
+    TOFFOLI,
     U1,
     U2,
     U3,
@@ -67,6 +66,7 @@ from .gates import (
     Z,
 )
 from .inverse_gate import inverse_gate
+from .parameter import CONST, Parameter
 from .parameter_mapping import (
     LinearParameterFunction,
     LinearParameterMapping,
@@ -111,6 +111,7 @@ __all__ = [
     "CNOT",
     "CZ",
     "SWAP",
+    "TOFFOLI",
     "Pauli",
     "PauliRotation",
     "ParametricRX",
