@@ -14,16 +14,15 @@ from typing import Optional, Union
 
 from .circuit import GateSequence, NonParametricQuantumCircuit
 from .circuit_parametric import (
-    CONST,
     ImmutableBoundParametricQuantumCircuit,
     ImmutableUnboundParametricQuantumCircuit,
     MutableUnboundParametricQuantumCircuitProtocol,
-    Parameter,
     UnboundParametricQuantumCircuit,
     UnboundParametricQuantumCircuitBase,
     UnboundParametricQuantumCircuitProtocol,
 )
 from .gate import ParametricQuantumGate, QuantumGate
+from .parameter import CONST, Parameter
 from .parameter_mapping import LinearParameterMapping, ParameterOrLinearFunction
 
 
@@ -57,10 +56,11 @@ class LinearMappedUnboundParametricQuantumCircuitBase(
         return self._param_mapping.is_trivial_mapping
 
     @property
-    def mapping_and_raw_circuit(
-        self,
-    ) -> tuple[LinearParameterMapping, ImmutableUnboundParametricQuantumCircuit]:
-        return (self._param_mapping, self._circuit.freeze())
+    def param_mapping(self) -> LinearParameterMapping:
+        return self._param_mapping
+
+    def primitive_circuit(self) -> ImmutableUnboundParametricQuantumCircuit:
+        return self._circuit.freeze()
 
     def get_mutable_copy(self) -> "LinearMappedUnboundParametricQuantumCircuit":
         circuit = LinearMappedUnboundParametricQuantumCircuit(self.qubit_count)
