@@ -17,6 +17,7 @@ from .gate_kind_decomposer import (
     CZ2RXRYCNOTTranspiler,
     H2RXRYTranspiler,
     H2RZSqrtXTranspiler,
+    Identity2RZTranspiler,
     RX2RZSqrtXTranspiler,
     RY2RZSqrtXTranspiler,
     S2RZTranspiler,
@@ -32,6 +33,7 @@ from .gate_kind_decomposer import (
     SWAP2CNOTTranspiler,
     T2RZTranspiler,
     Tdag2RZTranspiler,
+    TOFFOLI2HTTdagCNOTTranspiler,
     U1ToRZTranspiler,
     U2ToRXRZTranspiler,
     U2ToRZSqrtXTranspiler,
@@ -73,10 +75,12 @@ RZSetTranspiler: Callable[[], CircuitTranspiler] = lambda: SequentialTranspiler(
                 CZ2CNOTHTranspiler(),
                 PauliDecomposeTranspiler(),
                 PauliRotationDecomposeTranspiler(),
+                TOFFOLI2HTTdagCNOTTranspiler(),
             ]
         ),
         ParallelDecomposer(
             [
+                Identity2RZTranspiler(),
                 Y2RZXTranspiler(),
                 Z2RZTranspiler(),
                 H2RZSqrtXTranspiler(),
@@ -107,10 +111,12 @@ RotationSetTranspiler: Callable[[], CircuitTranspiler] = lambda: SequentialTrans
             [
                 PauliDecomposeTranspiler(),
                 PauliRotationDecomposeTranspiler(),
+                TOFFOLI2HTTdagCNOTTranspiler(),
             ]
         ),
         ParallelDecomposer(
             [
+                Identity2RZTranspiler(),
                 H2RXRYTranspiler(),
                 X2RXTranspiler(),
                 Y2RYTranspiler(),
@@ -145,6 +151,7 @@ __all__ = [
     "RotationSetTranspiler",
     "CliffordApproximationTranspiler",
     "IdentityInsertionTranspiler",
+    "Identity2RZTranspiler",
     "PauliDecomposeTranspiler",
     "PauliRotationDecomposeTranspiler",
     "CNOT2CZHTranspiler",
@@ -169,6 +176,7 @@ __all__ = [
     "SWAP2CNOTTranspiler",
     "T2RZTranspiler",
     "Tdag2RZTranspiler",
+    "TOFFOLI2HTTdagCNOTTranspiler",
     "U1ToRZTranspiler",
     "U2ToRXRZTranspiler",
     "U2ToRZSqrtXTranspiler",
